@@ -9,7 +9,7 @@ pub use crate::mry::*;
 use mock::*;
 pub use mock_locator::*;
 pub use mocks::*;
-pub use mry_macros::{mry, new, lock, m};
+pub use mry_macros::{lock, m, mry, new};
 pub use rule::*;
 pub use static_mocks::*;
 pub use Matcher::Any;
