@@ -26,15 +26,21 @@ impl<I, O> Mock<I, O> {
     }
 }
 
+impl<I: PartialEq + Clone, O> Mock<I, O> {
+    fn handle_assert_called(&self, matcher: &Matcher<I>, f: impl FnOnce()) -> Logs<I> {
+        let logs = self.logs.lock().filter_matches(matcher);
+        if logs.is_empty() {
+            f();
+        }
+        logs
+    }
+}
+
 impl<I: Clone + PartialEq + Debug, O: Debug> Mock<I, O> {
-    pub(crate) fn returns_with<B: Into<Behavior<I, O>>>(
-        &mut self,
-        matcher: Matcher<I>,
-        behavior: B,
-    ) {
+    pub(crate) fn returns_with(&mut self, matcher: Matcher<I>, behavior: Behavior<I, O>) {
         self.rules.push(Rule {
             matcher,
-            behavior: behavior.into(),
+            behavior: behavior,
         });
     }
 
@@ -55,15 +61,7 @@ impl<I: Clone + PartialEq + Debug, O: Debug> Mock<I, O> {
         }
     }
 
-    fn handle_assert_called(&self, matcher: &Matcher<I>, f: impl FnOnce()) -> Logs<I> {
-        let logs = self.logs.lock().filter_matches(matcher);
-        if logs.is_empty() {
-            f();
-        }
-        logs
-    }
-
-    pub fn record_call_and_find_mock_output(&mut self, input: I) -> Option<O> {
+    pub(crate) fn record_call_and_find_mock_output(&mut self, input: I) -> Option<O> {
         self.logs.lock().push(input.clone());
         for rule in &mut self.rules {
             match rule.called(&input) {
@@ -75,12 +73,14 @@ impl<I: Clone + PartialEq + Debug, O: Debug> Mock<I, O> {
         panic!("mock not found for {}\n{:?}", self.name, self.rules)
     }
 }
-impl<I, O: Clone + Send + Sync + 'static> Mock<I, O> {
+
+impl<I, O> Mock<I, O>
+where
+    I: Clone + PartialEq + Debug + Send + Sync + 'static,
+    O: Clone + Debug + Send + Sync + 'static,
+{
     pub(crate) fn returns(&mut self, matcher: Matcher<I>, ret: O) {
-        self.rules.push(Rule {
-            matcher,
-            behavior: Behavior::Const(RwLock::new(Box::new(repeat(ret)))),
-        });
+        self.returns_with(matcher, Behavior::Const(RwLock::new(Box::new(repeat(ret)))))
     }
 }
 
@@ -92,7 +92,7 @@ mod test {
     #[test]
     fn returns_with() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         assert_eq!(
             mock.record_call_and_find_mock_output(3),
@@ -121,7 +121,7 @@ mod test {
     #[should_panic(expected = "mock not found for a")]
     fn returns_with_never() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Never, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Never, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.record_call_and_find_mock_output(3);
     }
@@ -129,7 +129,7 @@ mod test {
     #[test]
     fn returns_with_always() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         assert_eq!(
             mock.record_call_and_find_mock_output(3),
@@ -177,7 +177,7 @@ mod test {
     #[test]
     fn assert_called_with() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.record_call_and_find_mock_output(3);
 
@@ -188,7 +188,7 @@ mod test {
     #[should_panic(expected = "a was not called")]
     fn assert_called_with_not_eq() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.record_call_and_find_mock_output(3);
 
@@ -199,7 +199,7 @@ mod test {
     #[should_panic(expected = "a was not called")]
     fn assert_called_with_panics() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.assert_called(Matcher::Eq(3));
     }
@@ -208,7 +208,7 @@ mod test {
     #[should_panic(expected = "[1, 2, 2]")]
     fn assert_called_with_log() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
         mock.record_call_and_find_mock_output(1);
         mock.record_call_and_find_mock_output(2);
         mock.record_call_and_find_mock_output(2);
@@ -219,7 +219,7 @@ mod test {
     #[test]
     fn assert_called_returns_logs() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.record_call_and_find_mock_output(3);
         mock.record_call_and_find_mock_output(3);
@@ -237,7 +237,7 @@ mod test {
     #[test]
     fn assert_called_returns_logs_matching() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)));
+        mock.returns_with(Matcher::Any, Behavior1::from(|a| "a".repeat(a)).into());
 
         mock.record_call_and_find_mock_output(2);
         mock.record_call_and_find_mock_output(3);
@@ -255,11 +255,14 @@ mod test {
 
     #[test]
     #[should_panic(
-        expected = "[Rule { matcher: Eq(3), behavior: Const(\"42\") }, Rule { matcher: Eq(3), behavior: CallsRealImpl }]"
+        expected = "[Rule { matcher: Eq(3), behavior: Function(_) }, Rule { matcher: Eq(3), behavior: CallsRealImpl }]"
     )]
     fn mock_not_found_with_rules() {
         let mut mock = Mock::<usize, String>::new("a");
-        mock.returns(Matcher::Eq(3), "42".into());
+        mock.returns_with(
+            Matcher::Eq(3),
+            Behavior::Function(Box::new(|_| "42".to_string())),
+        );
         mock.calls_real_impl(Matcher::Eq(3));
 
         mock.record_call_and_find_mock_output(2);
