@@ -1,13 +1,15 @@
-use std::fmt::Debug;
 use std::marker::PhantomData;
-use std::ops::DerefMut;
+use std::{any::TypeId, fmt::Debug};
 
-use crate::{Behavior, Matcher, Mock, MockResult, Mocks};
+use crate::mock::Mock;
+use crate::{Behavior, Matcher, MockGetter, MockResult};
 
 /// Mock locator returned by mock_* methods
-pub struct MockLocator<M, I, O, B> {
+pub struct MockLocator<'a, I, O, B> {
     #[doc(hidden)]
-    pub mocks: M,
+    pub mocks: Box<dyn MockGetter<I, O> + 'a>,
+    #[doc(hidden)]
+    pub key: TypeId,
     #[doc(hidden)]
     pub name: &'static str,
     #[doc(hidden)]
@@ -16,9 +18,8 @@ pub struct MockLocator<M, I, O, B> {
     pub _phantom: PhantomData<fn() -> (I, O, B)>,
 }
 
-impl<M, I, O, B> MockLocator<M, I, O, B>
+impl<'a, I, O, B> MockLocator<'a, I, O, B>
 where
-    M: DerefMut<Target = Mocks>,
     I: Clone + PartialEq + Debug + Send + Sync + 'static,
     O: Debug + Send + Sync + 'static,
     B: Into<Behavior<I, O>>,
@@ -28,7 +29,7 @@ where
     pub fn returns_with<T: Into<B>>(&mut self, behavior: T) {
         let matcher = self.matcher();
         self.get_mut_or_default()
-            .returns_with(matcher, behavior.into());
+            .returns_with(matcher, behavior.into().into());
     }
 
     /// This make the mock calls real impl. This is used for partial mocking.
@@ -46,11 +47,10 @@ where
     }
 }
 
-impl<M, I, O, B> MockLocator<M, I, O, B>
+impl<'a, I, O, B> MockLocator<'a, I, O, B>
 where
-    M: DerefMut<Target = Mocks>,
-    I: Send + Sync + 'static,
-    O: Clone + Send + Sync + 'static,
+    I: Clone + PartialEq + Debug + Send + Sync + 'static,
+    O: Clone + Debug + Send + Sync + 'static,
 {
     /// This makes the mock returns the given constant value.
     /// This requires `Clone`. For returning not clone value, use `returns_with`.
@@ -60,19 +60,23 @@ where
     }
 }
 
-impl<M, I, O, B> MockLocator<M, I, O, B>
+impl<'a, I, O, B> MockLocator<'a, I, O, B>
 where
-    M: DerefMut<Target = Mocks>,
     I: Send + Sync + 'static,
     O: Send + Sync + 'static,
 {
     fn get_mut_or_default(&mut self) -> &mut Mock<I, O> {
-        self.mocks.get_mut_or_create::<I, O>(self.name)
+        self.mocks.get_mut_or_create(self.key.clone(), &self.name)
     }
-
+}
+impl<'a, I, O, B> MockLocator<'a, I, O, B>
+where
+    I: Send + Sync + 'static,
+    O: Send + Sync + 'static,
+{
     fn get_or_error(&self) -> &Mock<I, O> {
         self.mocks
-            .get::<Mock<I, O>>(self.name)
+            .get(&self.key, &self.name)
             .expect(&format!("no mock is found for {}", self.name))
     }
 
